@@ -50,7 +50,7 @@ usage() {
     echo ""
 }
 
-NVIDIA_BUG_REPORT_CHANGE='$Change: 20724502 $'
+NVIDIA_BUG_REPORT_CHANGE='$Change: 21728654 $'
 NVIDIA_BUG_REPORT_VERSION=`echo "$NVIDIA_BUG_REPORT_CHANGE" | tr -c -d "[:digit:]"`
 
 # Set the default filename so that it won't be empty in the usage message
@@ -93,7 +93,7 @@ echo_metadata() {
     if [ $? -ne 0 ]; then
         # Run dumb ls -l. We might not get one-second mtime granularity, but
         # that is probably okay.
-        ls -l "$1"
+        ls -l "$1" 2>&1
     fi
 }
 
