@@ -1,6 +1,6 @@
  /***************************************************************************\
 |*                                                                           *|
-|*       Copyright 1993-2015 NVIDIA, Corporation.  All rights reserved.      *|
+|*       Copyright 1993-2016 NVIDIA, Corporation.  All rights reserved.      *|
 |*                                                                           *|
 |*     NOTICE TO USER:   The source code  is copyrighted under  U.S. and     *|
 |*     international laws.  Users and possessors of this source code are     *|
@@ -71,15 +71,31 @@ extern "C" {
 |*                                 Typedefs                                  *|
  \***************************************************************************/
 
-typedef unsigned char      NvV8;  /* "void": enumerated or multiple fields   */
-typedef unsigned short     NvV16; /* "void": enumerated or multiple fields   */
-typedef unsigned char      NvU8;  /* 0 to 255                                */
-typedef unsigned short     NvU16; /* 0 to 65535                              */
-typedef signed char        NvS8;  /* -128 to 127                             */
-typedef signed short       NvS16; /* -32768 to 32767                         */
+// Floating point types
 typedef float              NvF32; /* IEEE Single Precision (S1E8M23)         */
 typedef double             NvF64; /* IEEE Double Precision (S1E11M52)        */
 
+
+// 8-bit: 'char' is the only 8-bit in the C89 standard and after.
+typedef unsigned char      NvV8; /* "void": enumerated or multiple fields    */
+typedef unsigned char      NvU8; /* 0 to 255                                 */
+typedef   signed char      NvS8; /* -128 to 127                              */
+
+
+// 16-bit: If the compiler tells us what we can use, then use it.
+#ifdef __INT16_TYPE__
+typedef unsigned __INT16_TYPE__ NvV16; /* "void": enumerated or multiple fields */
+typedef unsigned __INT16_TYPE__ NvU16; /* 0 to 65535                            */
+typedef   signed __INT16_TYPE__ NvS16; /* -32768 to 32767                       */
+
+// The minimal standard for C89 and after
+#else       // __INT16_TYPE__
+typedef unsigned short     NvV16; /* "void": enumerated or multiple fields   */
+typedef unsigned short     NvU16; /* 0 to 65535                              */
+typedef   signed short     NvS16; /* -32768 to 32767                         */
+#endif      // __INT16_TYPE__
+
+
 // Macros to get the MSB and LSB of a 16 bit unsigned number
 #define NvU16_HI08(n) ((NvU8)(((NvU16)(n)) >> 8))
 #define NvU16_LO08(n) ((NvU8)((NvU16)(n)))
@@ -94,9 +110,19 @@ typedef char*              NVREGSTR;
 typedef NvU8*              NVREGSTR;
 #endif
 
-/* mainly for 64-bit linux, where long is 64 bits
- * and win9x, where int is 16 bit.
- */
+
+// 32-bit: If the compiler tells us what we can use, then use it.
+#ifdef __INT32_TYPE__
+typedef unsigned __INT32_TYPE__ NvV32; /* "void": enumerated or multiple fields */
+typedef unsigned __INT32_TYPE__ NvU32; /* 0 to 4294967295                       */
+typedef   signed __INT32_TYPE__ NvS32; /* -2147483648 to 2147483647             */
+
+// Older compilers
+#else       // __INT32_TYPE__
+
+// For historical reasons, NvU32/NvV32 are defined to different base intrinsic
+// types than NvS32 on some platforms.
+// Mainly for 64-bit linux, where long is 64 bits and win9x, where int is 16 bit.
 #if (defined(NV_UNIX) || defined(vxworks) || defined(NV_WINDOWS_CE) ||  \
      defined(__arm) || defined(__IAR_SYSTEMS_ICC__) || defined(NV_QNX) || \
      defined(NV_INTEGRITY) || defined(NV_HOS) || defined(NV_MODS) || \
@@ -104,27 +130,34 @@ typedef NvU8*              NVREGSTR;
     (!defined(NV_MACINTOSH) || defined(NV_MACINTOSH_64))
 typedef unsigned int       NvV32; /* "void": enumerated or multiple fields   */
 typedef unsigned int       NvU32; /* 0 to 4294967295                         */
-#else
+
+// The minimal standard for C89 and after
+#else       // (defined(NV_UNIX) || defined(vxworks) || ...
 typedef unsigned long      NvV32; /* "void": enumerated or multiple fields   */
 typedef unsigned long      NvU32; /* 0 to 4294967295                         */
-#endif
+#endif      // (defined(NV_UNIX) || defined(vxworks) || ...
 
-// mac os 32-bit still needs this
+// Mac OS 32-bit still needs this
 #if defined(NV_MACINTOSH) && !defined(NV_MACINTOSH_64)
-typedef signed long        NvS32; /* -2147483648 to 2147483647               */
+typedef   signed long      NvS32; /* -2147483648 to 2147483647               */
 #else
-typedef signed int         NvS32; /* -2147483648 to 2147483647               */
-#endif
+typedef   signed int       NvS32; /* -2147483648 to 2147483647               */
+#endif      // defined(NV_MACINTOSH) && !defined(NV_MACINTOSH_64)
+#endif      // __INT32_TYPE__
 
-/* 64-bit types for compilers that support them, plus some obsolete variants */
+
+
+// 64-bit types for compilers that support them, plus some obsolete variants
 #if defined(__GNUC__) || defined(__clang__) || defined(__arm) || \
     defined(__IAR_SYSTEMS_ICC__) || defined(__ghs__) || defined(_WIN64) || \
     defined(__SUNPRO_C) || defined(__SUNPRO_CC) || defined (__xlC__)
-typedef unsigned long long NvU64; /* 0 to 18446744073709551615          */
-typedef          long long NvS64; /* 2^-63 to 2^63-1                    */
+typedef unsigned long long NvU64; /* 0 to 18446744073709551615                      */
+typedef          long long NvS64; /* -9223372036854775808 to 9223372036854775807    */
+
+// Microsoft since 2003 -- https://msdn.microsoft.com/en-us/library/29dh1w7z.aspx
 #else
-typedef unsigned __int64   NvU64; /* 0 to 18446744073709551615              */
-typedef          __int64   NvS64; /* 2^-63 to 2^63-1                        */
+typedef unsigned __int64   NvU64; /* 0 to 18446744073709551615                      */
+typedef          __int64   NvS64; /* -9223372036854775808 to 9223372036854775807    */
 #endif
 
 #ifdef NV_TYPESAFE_HANDLES
@@ -134,7 +167,7 @@ typedef          __int64   NvS64; /* 2^-63 to 2^63-1                        */
  * have transistioned safely to NvHandle.
  * The plan is to then eventually scale up the handle to be 64-bits.
  */
-typedef struct 
+typedef struct
 {
     NvU32 val;
 } NvHandle;
@@ -325,6 +358,12 @@ typedef unsigned char *PUCHAR;
 
 #if defined(_MSC_VER)
 
+    #if _MSC_VER >= 1310
+    #define NV_NOINLINE __declspec(noinline)
+    #else
+    #define NV_NOINLINE
+    #endif
+
     #define NV_INLINE __inline
 
     #if _MSC_VER >= 1200
@@ -340,9 +379,37 @@ typedef unsigned char *PUCHAR;
 
     #define NV_FORCERESULTCHECK
 
+    #define NV_ATTRIBUTE_UNUSED
+
 #else // ! defined(_MSC_VER)
 
-    #if defined(__GNUC__) || defined(__clang__) || defined(__INTEL_COMPILER)
+    #if defined(__GNUC__)
+        #if (__GNUC__ > 3) || \
+            (__GNUC__ == 3 && __GNUC_MINOR__ >= 1 && __GNUC_PATCHLEVEL__ >= 1)
+        #define NV_NOINLINE __attribute__((noinline))
+        #endif
+    #elif defined(__clang__)
+        #if __has_attribute(noinline)
+        #define NV_NOINLINE __attribute__((noinline))
+        #endif
+    #elif defined(__arm) && (__ARMCC_VERSION >= 300000)
+        #define NV_NOINLINE __attribute__((noinline))
+    #elif (defined(__SUNPRO_C) && (__SUNPRO_C >= 0x590)) ||\
+            (defined(__SUNPRO_CC) && (__SUNPRO_CC >= 0x590))
+        #define NV_NOINLINE __attribute__((noinline))
+    #elif defined (__INTEL_COMPILER)
+        #define NV_NOINLINE __attribute__((noinline))
+    #endif
+
+    #if !defined(NV_NOINLINE)
+    #define NV_NOINLINE
+    #endif
+
+    /* GreenHills compiler defines __GNUC__, but doesn't support
+     * __inline__ keyword. */
+    #if defined(__ghs__)
+    #define NV_INLINE inline
+    #elif defined(__GNUC__) || defined(__clang__) || defined(__INTEL_COMPILER)
     #define NV_INLINE __inline__
     #elif defined (macintosh) || defined(__SUNPRO_C) || defined(__SUNPRO_CC)
     #define NV_INLINE inline
@@ -354,7 +421,11 @@ typedef unsigned char *PUCHAR;
 
     /* Don't force inline on DEBUG builds -- it's annoying for debuggers. */
     #if !defined(DEBUG)
-        #if defined(__GNUC__)
+        /* GreenHills compiler defines __GNUC__, but doesn't support
+         * __attribute__ or __inline__ keyword. */
+        #if defined(__ghs__)
+            #define NV_FORCEINLINE inline
+        #elif defined(__GNUC__)
             // GCC 3.1 and beyond support the always_inline function attribute.
             #if (__GNUC__ > 3) || (__GNUC__ == 3 && __GNUC_MINOR__ >= 1)
             #define NV_FORCEINLINE __attribute__((always_inline)) __inline__
@@ -405,6 +476,12 @@ typedef unsigned char *PUCHAR;
         #define NV_FORCERESULTCHECK
     #endif
 
+    #if defined(__GNUC__) || defined(__clang__) || defined(__INTEL_COMPILER)
+        #define NV_ATTRIBUTE_UNUSED __attribute__((unused))
+    #else
+        #define NV_ATTRIBUTE_UNUSED
+    #endif
+
 #endif  // defined(_MSC_VER)
 
 /*!
@@ -458,6 +535,7 @@ typedef NvUFXP32                                                    NvUFXP25_7;
 typedef NvUFXP32                                                    NvUFXP28_4;
 
 typedef NvU64                                                      NvUFXP48_16;
+typedef NvU64                                                      NvUFXP52_12;
 
 /*!
  * Utility macros used in converting between signed integers and fixed-point
@@ -555,7 +633,7 @@ typedef NvU64                                                      NvUFXP48_16;
 //
 // 32-bit Signed FXP:
 // Some compilers do not support left shift negative values
-// so typecast integer to NvU32 instead of NvS32 
+// so typecast integer to NvU32 instead of NvS32
 //
 #define NV_TYPES_S32_TO_SFXP_X_Y(x, y, integer)                               \
     ((NvSFXP##x##_##y) (((NvU32) (integer)) <<                                \
