@@ -176,6 +176,11 @@ int NVKMS_API_CALL nvkms_copyout(NvU64 uaddr, const void *kptr, size_t n)
     return copyout(kptr, nvKmsNvU64ToPointer(uaddr), n);
 }
 
+void NVKMS_API_CALL nvkms_yield(void)
+{
+    pause("yield", 1 /* timeout in 1/hz units */);
+}
+
 int NVKMS_API_CALL nvkms_snprintf(char *str, size_t size, const char *format, ...)
 {
     int ret;
@@ -739,7 +744,7 @@ static int nvkms_ioctl(
     u_long cmd,
     caddr_t data,
     int fflag,
-    d_thread_t *td
+    struct thread *td
 )
 {
     u_long nr, size;
@@ -781,7 +786,7 @@ static int nvkms_open(
     struct cdev *dev,
     int oflags,
     int devtype,
-    d_thread_t *td
+    struct thread *td
 )
 {
     struct nvkms_per_open *popen;
@@ -797,7 +802,7 @@ static int nvkms_open(
     nvkms_module.client_counter += 1;
     sx_xunlock(&nvkms_module.lock);
 
-    popen = nvkms_alloc(sizeof(*popen), NV_FALSE);
+    popen = nvkms_alloc(sizeof(*popen), NV_TRUE);
     if (popen == NULL) {
         return ENOMEM;
     }
@@ -829,7 +834,7 @@ static int nvkms_open(
 static int nvkms_poll(
     struct cdev *dev,
     int events,
-    d_thread_t *td
+    struct thread *td
 )
 {
     struct nvkms_per_open *popen;
