@@ -102,6 +102,8 @@ enum NvKmsSurfaceMemoryFormat {
     NvKmsSurfaceMemoryFormatX8R8G8B8    = 5,
     NvKmsSurfaceMemoryFormatA2B10G10R10 = 6,
     NvKmsSurfaceMemoryFormatX2B10G10R10 = 7,
+    NvKmsSurfaceMemoryFormatA8B8G8R8    = 8,
+    NvKmsSurfaceMemoryFormatX8B8G8R8    = 9,
 };
 
 static inline NvU8 nvKmsSurfaceMemoryFormatToBpp
@@ -119,6 +121,8 @@ static inline NvU8 nvKmsSurfaceMemoryFormatToBpp
             return  16;
         case NvKmsSurfaceMemoryFormatA8R8G8B8:
         case NvKmsSurfaceMemoryFormatX8R8G8B8:
+        case NvKmsSurfaceMemoryFormatA8B8G8R8:
+        case NvKmsSurfaceMemoryFormatX8B8G8R8:
         case NvKmsSurfaceMemoryFormatA2B10G10R10:
         case NvKmsSurfaceMemoryFormatX2B10G10R10:
             return  32;
@@ -142,10 +146,12 @@ static inline NvU8 nvKmsSurfaceMemoryFormatToDepth
         case NvKmsSurfaceMemoryFormatR5G6B5:
             return 16;
         case NvKmsSurfaceMemoryFormatX8R8G8B8:
+        case NvKmsSurfaceMemoryFormatX8B8G8R8:
             return 24;
         case NvKmsSurfaceMemoryFormatX2B10G10R10:
             return 30;
         case NvKmsSurfaceMemoryFormatA8R8G8B8:
+        case NvKmsSurfaceMemoryFormatA8B8G8R8:
         case NvKmsSurfaceMemoryFormatA2B10G10R10:
             return 32;
     }
@@ -179,11 +185,53 @@ static inline const char *NvKmsSurfaceMemoryFormatToString
             return "A2B10G10R10";
         case NvKmsSurfaceMemoryFormatX2B10G10R10:
             return "X2B10G10R10";
+        case NvKmsSurfaceMemoryFormatA8B8G8R8:
+            return "A8B8G8R8";
+        case NvKmsSurfaceMemoryFormatX8B8G8R8:
+            return "X8B8G8R8";
     }
 
     return "Unknown";
 }
 
+/*!
+ * Description of Notifiers and Semaphores (Non-isochronous (NISO) surfaces).
+ *
+ * When flipping, the client can optionally specify a notifier and/or
+ * a semaphore to use with the flip.  The surfaces used for these
+ * should be registered with NVKMS to get an NvKmsSurfaceHandle.
+ *
+ * NvKmsNIsoSurface::offsetInWords indicates the starting location, in
+ * 32-bit words, within the surface where EVO should write the
+ * notifier or semaphore.  Note that only the first 4096 bytes of a
+ * surface can be used by semaphores or notifiers; offsetInWords must
+ * allow for the semaphore or notifier to be written within the first
+ * 4096 bytes of the surface.  I.e., this must be satisfied:
+ *
+ *   ((offsetInWords * 4) + elementSizeInBytes) <= 4096
+ *
+ * Where elementSizeInBytes is:
+ *
+ *  if NISO_FORMAT_FOUR_WORD*, elementSizeInBytes = 16
+ *  if NISO_FORMAT_LEGACY,
+ *    if overlay && notifier, elementSizeInBytes = 16
+ *    else, elementSizeInBytes = 4
+ *
+ *  Note that different GPUs support different semaphore and notifier formats.
+ *  Check NvKmsAllocDeviceReply::validNIsoFormatMask to determine which are
+ *  valid for the given device.
+ *
+ *  Note also that FOUR_WORD and FOUR_WORD_NVDISPLAY are the same size, but
+ *  FOUR_WORD uses a format compatible with display class 907[ce], and
+ *  FOUR_WORD_NVDISPLAY uses a format compatible with c37e (actually defined by
+ *  the NV_DISP_NOTIFIER definition in clc37d.h).
+ */
+enum NvKmsNIsoFormat {
+    NVKMS_NISO_FORMAT_LEGACY,
+    NVKMS_NISO_FORMAT_FOUR_WORD,
+    NVKMS_NISO_FORMAT_FOUR_WORD_NVDISPLAY,
+};
+
 enum NvKmsEventType {
     NVKMS_EVENT_TYPE_DPY_CHANGED,
     NVKMS_EVENT_TYPE_DYNAMIC_DPY_CONNECTED,
