@@ -21,8 +21,11 @@
 
 #include <sys/param.h>
 
-#if __FreeBSD_version >= 1100000
-#error This driver does not support FreeBSD 11.x/-CURRENT!
+#if __FreeBSD_version >= 1200000
+#error This driver does not support FreeBSD 12.x/-CURRENT!
+#endif
+#if __FreeBSD_version >= 1100000 && __FreeBSD_version < 1100122
+#error This driver requires FreeBSD 11.0 or later!
 #endif
 #if __FreeBSD_version >= 1000000 && __FreeBSD_version < 1000510
 #error This driver requires FreeBSD 10.0 or later!
@@ -449,4 +452,16 @@ int    nvidia_mmap_dev_single(nv_state_t *, struct nvidia_filep *, vm_ooffset_t
 void   nvidia_modeset_suspend(NvU32 gpu_id);
 void   nvidia_modeset_resume (NvU32 gpu_id);
 
+static inline NvBool nvidia_lock_init_locks(nvidia_stack_t *sp, nv_state_t *nv)
+{
+    return rm_init_event_locks(sp, nv);
+}
+
+static inline void nvidia_lock_destroy_locks(nvidia_stack_t *sp, nv_state_t *nv)
+{
+    rm_destroy_event_locks(sp, nv);
+}
+
+
+
 #endif /* __NV_FREEBSD_H__ */
