@@ -1,6 +1,6 @@
 /* _NVRM_COPYRIGHT_BEGIN_
  *
- * Copyright 1999-2015 by NVIDIA Corporation.  All rights reserved.  All
+ * Copyright 1999-2016 by NVIDIA Corporation.  All rights reserved.  All
  * information contained herein is proprietary and confidential to NVIDIA
  * Corporation.  Any use, reproduction, or disclosure without the written
  * permission of NVIDIA Corporation is prohibited.
@@ -15,6 +15,9 @@
 #include <nvtypes.h>
 #include <nvCpuUuid.h>
 #include <stdarg.h>
+#ifndef __KERNEL__
+#include "g_nvconfig.h"
+#endif
 
 #if !defined(NV_MIN)
 #define NV_MIN(_a,_b) ((_a) < (_b) ? (_a) : (_b))
@@ -50,6 +53,7 @@ typedef struct {
 #define NV_ESC_STATUS_CODE       (NV_IOCTL_BASE + 9)
 #define NV_ESC_CHECK_VERSION_STR (NV_IOCTL_BASE + 10)
 #define NV_ESC_IOCTL_XFER_CMD    (NV_IOCTL_BASE + 11)
+#define NV_ESC_ATTACH_GPUS_TO_FD (NV_IOCTL_BASE + 12)
 
 /*
  * #define an absolute maximum used as a sanity check for the
@@ -313,7 +317,7 @@ typedef struct nv_mmap_context_s
     NvP64 addr;
     NvU64 size;
     NvU32 process_id;
-    NvU32 thread_id;
+    NvU64 thread_id;
     void *file;
     void *os_priv;
     struct nv_mmap_context_s *next;
@@ -361,8 +365,12 @@ typedef struct
     /* list of events allocated for this device */
     nv_event_t *event_list;
 
+    /* lock to protect event_list */
+    void *event_spinlock;
+
     nv_kern_mapping_t *kern_mappings;
 
+    void *mmap_mutex;
     nv_mmap_context_t *mmap_contexts;
 
     /* DMA addressable range of the device */
@@ -384,7 +392,10 @@ typedef struct gpuVaAllocInfo                       *nvgpuVaAllocInfo_t;
 typedef struct gpuMapInfo                           *nvgpuMapInfo_t;
 typedef struct UvmGpuFbInfo_tag                     *nvgpuFbInfo_t;
 typedef struct UvmGpuFaultInfo_tag                  *nvgpuFaultInfo_t;
-typedef struct UvmGpuAccessCntrInfo_tag             *nvgpuAccessCntrInfo_t;
+
+
+
+
 typedef struct UvmGpuInfo_tag                       *nvgpuInfo_t;
 typedef struct gpuPageLevelInfo                     *nvgpuPageLevelInfo_t;
 typedef struct gpuChannelPhysInfo                   *nvgpuChannelPhysInfo_t;
@@ -418,7 +429,6 @@ typedef NV_STATUS (*nvPmaEvictRangeCallback)(void *, NvU64, NvU64);
 #define NV_FLAG_IN_RECOVERY            0x1000
 #define NV_FLAG_SKIP_CFG_CHECK         0x2000
 #define NV_FLAG_UNBIND_LOCK            0x4000
-#define NV_FLAG_ACQ_GPU_LOCK           0x8000
 
 #define NV_PM_ACPI_HIBERNATE    0x0001
 #define NV_PM_ACPI_STANDBY      0x0002
@@ -426,7 +436,8 @@ typedef NV_STATUS (*nvPmaEvictRangeCallback)(void *, NvU64, NvU64);
 
 #define NV_PRIMARY_VGA(nv)      ((nv)->primary_vga)
 
-#define NV_IS_GVI_DEVICE(nv) ((nv)->flags & NV_FLAG_GVI)
+#define NV_IS_GVI_DEVICE(nv)    ((nv)->flags & NV_FLAG_GVI)
+#define NV_IS_CTL_DEVICE(nv)    ((nv)->flags & NV_FLAG_CONTROL)
 
 /*
  * The ACPI specification defines IDs for various ACPI video
@@ -596,7 +607,8 @@ void*      NV_API_CALL  nv_alloc_kernel_mapping  (nv_state_t *, void *, NvU64, N
 NV_STATUS  NV_API_CALL  nv_free_kernel_mapping   (nv_state_t *, void *, void *, void *);
 NV_STATUS  NV_API_CALL  nv_alloc_user_mapping    (nv_state_t *, void *, NvU64, NvU32, NvU64, NvU32, NvU64 *, void **);
 NV_STATUS  NV_API_CALL  nv_free_user_mapping     (nv_state_t *, void *, NvU64, void *);
-NV_STATUS  NV_API_CALL  nv_create_user_mapping_context (nv_state_t *, NvU64, NvU64, void **);
+NV_STATUS  NV_API_CALL  nv_create_user_mapping_context (nv_state_t *, NvU64, NvU64, NvU32, void *, NvU64, void *, void **);
+void       NV_API_CALL  nv_destroy_user_mapping_context (nv_state_t *, void *, void *);
 
 NvU64  NV_API_CALL  nv_get_kern_phys_address     (NvU64);
 NvU64  NV_API_CALL  nv_get_user_phys_address     (NvU64);
@@ -656,6 +668,11 @@ NvBool     NV_API_CALL  nv_is_virtualized_system  (nv_stack_t *);
 nv_fd_memdesc_t* NV_API_CALL nv_get_fd_memdesc   (void *);
 NV_STATUS  NV_API_CALL  nv_add_fd_memdesc_to_fd  (NvU32, const nv_fd_memdesc_t*);
 
+NV_STATUS NV_API_CALL nv_export_rm_object_to_fd    (NvHandle, NvS32);
+NV_STATUS NV_API_CALL nv_import_rm_object_from_fd  (NvS32, NvHandle *);
+
+NV_STATUS NV_API_CALL nv_get_device_memory_config(nv_state_t *, NvU32 *, NvU32 *, NvU32 *,
+                                                  NvU32 *, NvS32 *);
 /*
  * ---------------------------------------------------------------------------
  *
@@ -679,6 +696,7 @@ NV_STATUS  NV_API_CALL  rm_release_api_lock      (nvidia_stack_t *);
 NV_STATUS  NV_API_CALL  rm_ioctl                 (nvidia_stack_t *, nv_state_t *, void *, NvU32, void *, NvU32);
 BOOL       NV_API_CALL  rm_isr                   (nvidia_stack_t *, nv_state_t *, NvU32 *);
 void       NV_API_CALL  rm_isr_bh                (nvidia_stack_t *, nv_state_t *);
+void       NV_API_CALL  rm_isr_bh_unlocked       (nvidia_stack_t *, nv_state_t *);
 NV_STATUS  NV_API_CALL  rm_power_management      (nvidia_stack_t *, nv_state_t *, NvU32, NvU32);
 NV_STATUS  NV_API_CALL  rm_save_low_res_mode     (nvidia_stack_t *, nv_state_t *);
 NV_STATUS  NV_API_CALL  rm_get_vbios_version     (nvidia_stack_t *, nv_state_t *, NvU32 *, NvU32 *, NvU32 *, NvU32 *, NvU32 *);
@@ -686,12 +704,15 @@ NV_STATUS  NV_API_CALL  rm_get_gpu_uuid          (nvidia_stack_t *, nv_state_t *
 NV_STATUS  NV_API_CALL  rm_get_gpu_uuid_raw      (nvidia_stack_t *, nv_state_t *, NvU8 **, NvU32 *);
 void       NV_API_CALL  rm_free_unused_clients   (nvidia_stack_t *, nv_state_t *, void *);
 void       NV_API_CALL  rm_unbind_lock           (nvidia_stack_t *, nv_state_t *);
-
+void       NV_API_CALL  rm_free_exported_object  (nvidia_stack_t *, NvHandle);
 NV_STATUS  NV_API_CALL  rm_read_registry_dword   (nvidia_stack_t *, nv_state_t *, NvU8 *, NvU8 *, NvU32 *);
 NV_STATUS  NV_API_CALL  rm_write_registry_dword  (nvidia_stack_t *, nv_state_t *, NvU8 *, NvU8 *, NvU32);
 NV_STATUS  NV_API_CALL  rm_read_registry_binary  (nvidia_stack_t *, nv_state_t *, NvU8 *, NvU8 *, NvU8 *, NvU32 *);
 NV_STATUS  NV_API_CALL  rm_write_registry_binary (nvidia_stack_t *, nv_state_t *, NvU8 *, NvU8 *, NvU8 *, NvU32);
 NV_STATUS  NV_API_CALL  rm_write_registry_string (nvidia_stack_t *, nv_state_t *, NvU8 *, NvU8 *, const char *, NvU32);
+void       NV_API_CALL  rm_parse_option_string   (nvidia_stack_t *, const char *);
+char*      NV_API_CALL  rm_remove_spaces         (const char *);
+char*      NV_API_CALL  rm_string_token          (char **, const char);
 
 NV_STATUS  NV_API_CALL  rm_run_rc_callback       (nvidia_stack_t *, nv_state_t *);
 void       NV_API_CALL  rm_execute_work_item     (nvidia_stack_t *, void *);
@@ -703,9 +724,7 @@ void       NV_API_CALL  rm_register_compatible_ioctls   (nvidia_stack_t *);
 void       NV_API_CALL  rm_unregister_compatible_ioctls (nvidia_stack_t *);
 
 BOOL       NV_API_CALL  rm_is_legacy_device      (nvidia_stack_t *, NvU16, NvU16, NvU16, BOOL);
-BOOL       NV_API_CALL  rm_is_legacy_arch        (NvU32, NvU32);
-NV_STATUS  NV_API_CALL  rm_is_supported_device   (nvidia_stack_t *, nv_state_t *, NvU32 *, NvU32 *);
-
+NV_STATUS  NV_API_CALL  rm_is_supported_device   (nvidia_stack_t *, nv_state_t *);
 
 void       NV_API_CALL  rm_check_pci_config_space (nvidia_stack_t *, nv_state_t *nv, BOOL, BOOL, BOOL);
 
@@ -777,8 +796,15 @@ NV_STATUS  NV_API_CALL rm_gpu_ops_get_gpu_ids(nvidia_stack_t *sp, NvU8 *pUuid, u
 NV_STATUS NV_API_CALL rm_gpu_ops_own_page_fault_intr(nvidia_stack_t *, NvU8 *, unsigned, NvBool);
 NV_STATUS  NV_API_CALL rm_gpu_ops_init_fault_info(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, nvgpuFaultInfo_t);
 NV_STATUS  NV_API_CALL rm_gpu_ops_destroy_fault_info(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, nvgpuFaultInfo_t);
-NV_STATUS  NV_API_CALL rm_gpu_ops_init_access_cntr_info(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, nvgpuAccessCntrInfo_t);
-NV_STATUS  NV_API_CALL rm_gpu_ops_destroy_access_cntr_info(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, nvgpuAccessCntrInfo_t);
+
+
+
+
+
+
+
+
+
 NV_STATUS  NV_API_CALL rm_gpu_ops_get_page_level_info(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvU64, nvgpuPageLevelInfo_t);
 NV_STATUS  NV_API_CALL rm_gpu_ops_get_channel_phys_info(nvidia_stack_t *, NvHandle, NvHandle, nvgpuChannelPhysInfo_t);
 void       NV_API_CALL rm_gpu_ops_free_mem_handles(nvidia_stack_t *, void**, NvU32);
@@ -795,17 +821,38 @@ void       NV_API_CALL rm_gpu_ops_p2p_object_destroy(nvidia_stack_t *, nvgpuSess
 NV_STATUS  NV_API_CALL rm_gpu_ops_get_big_page_size(nvidia_stack_t*, nvgpuAddressSpaceHandle_t, NvU32 *);
 NV_STATUS  NV_API_CALL rm_gpu_ops_get_external_alloc_ptes(nvidia_stack_t*, nvgpuAddressSpaceHandle_t, NvHandle, NvU64, NvU64, nvgpuExternalMappingInfo_t);
 NV_STATUS  NV_API_CALL rm_gpu_ops_retain_channel(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvHandle, NvHandle, nvgpuChannelInstanceInfo_t);
-NV_STATUS  NV_API_CALL rm_gpu_ops_retain_channel_resources(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvP64, NvU32, nvgpuChannelResourceInfo_t);
-NV_STATUS  NV_API_CALL rm_gpu_ops_bind_channel_resources(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvP64, NvU32, nvgpuChannelResourceBindParams_t);
+NV_STATUS  NV_API_CALL rm_gpu_ops_retain_channel_resources(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvP64, NvU32, NvU32, nvgpuChannelResourceInfo_t);
+NV_STATUS  NV_API_CALL rm_gpu_ops_bind_channel_resources(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvP64, NvU32, NvU32, nvgpuChannelResourceBindParams_t);
 void       NV_API_CALL rm_gpu_ops_release_channel(nvidia_stack_t *, NvP64);
 void       NV_API_CALL rm_gpu_ops_release_channel_resources(nvidia_stack_t *, NvP64*, NvU32);
 void       NV_API_CALL rm_gpu_ops_stop_channel(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvP64, NvBool);
 NV_STATUS  NV_API_CALL rm_gpu_ops_get_channel_resource_ptes(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvP64, NvU64, NvU64, nvgpuExternalMappingInfo_t);
+
+
+
 void       NV_API_CALL rm_kernel_rmapi_op(nvidia_stack_t *sp, void *ops_cmd);
+NvBool     NV_API_CALL rm_get_device_remove_flag(nvidia_stack_t *sp, NvU32 gpu_id);
 NV_STATUS  NV_API_CALL rm_gpu_copy_mmu_faults(nvidia_stack_t *, nv_state_t *, NvU32 *);
 NV_STATUS  NV_API_CALL rm_gpu_copy_mmu_faults_unlocked(nvidia_stack_t *, nv_state_t *, NvU32 *);
 NV_STATUS  NV_API_CALL rm_gpu_need_4k_page_isolation(nv_state_t *, NvBool *);
-NvBool     NV_API_CALL rm_is_chipset_io_coherent(nv_stack_t *); 
+NvBool     NV_API_CALL rm_is_chipset_io_coherent(nv_stack_t *);
+NvBool     NV_API_CALL rm_init_event_locks(nvidia_stack_t *, nv_state_t *);
+void       NV_API_CALL rm_destroy_event_locks(nvidia_stack_t *, nv_state_t *);
+
+/* vGPU VFIO specific functions */
+NV_STATUS  NV_API_CALL  nv_vgpu_create_request(nvidia_stack_t *, nv_state_t *, NvU8 *, NvU32);
+NV_STATUS  NV_API_CALL  nv_vgpu_delete(nvidia_stack_t *, NvU8 *);
+NV_STATUS  NV_API_CALL  nv_vgpu_get_type_ids(nvidia_stack_t *, nv_state_t *, NvU32 *, NvU32 **);
+NV_STATUS  NV_API_CALL  nv_vgpu_get_type_info(nvidia_stack_t *, nv_state_t *, NvU32, NvU8 *, int);
+NV_STATUS  NV_API_CALL  nv_vgpu_get_bar_info(nvidia_stack_t *, nv_state_t *, NvU8 *, NvU64 *, NvU32, void *);
+NV_STATUS  NV_API_CALL  nv_vgpu_reg_access(nvidia_stack_t *, nv_state_t *, NvU8 *, NvU8 *, NvU32, NvU64 , NvS32 *, void *, NvBool, NvU32);
+NV_STATUS  NV_API_CALL  nv_vgpu_start(nvidia_stack_t *, NvU8 *, void *, NvS32 *, NvU8 *, NvU32, NvU8 *);
+NV_STATUS  NV_API_CALL  nv_vgpu_power_op(nvidia_stack_t *, nv_state_t *, NvU8 *, void *, NvS32 *, NvBool);
+NV_STATUS  NV_API_CALL  nv_vgpu_validate_map_request(nvidia_stack_t *, nv_state_t *, NvU8 *, NvU64 *, NvU64 *, NvU64 *);
+NV_STATUS  NV_API_CALL  nv_vgpu_get_sparse_mmap(nvidia_stack_t *, nv_state_t *, NvU8 *, NvU64 **, NvU64 **, NvU32 *);
+NV_STATUS  NV_API_CALL  nv_vgpu_update_request(nvidia_stack_t *, NvU8 *);
+NV_STATUS  NV_API_CALL  nv_gpu_bind_event(nvidia_stack_t *);
+
 #endif /* NVWATCH */
 
 #endif /* NVRM */
