@@ -1,6 +1,6 @@
 /* _NVRM_COPYRIGHT_BEGIN_
  *
- * Copyright 2001-2014 by NVIDIA Corporation.  All rights reserved.  All
+ * Copyright 2001-2016 by NVIDIA Corporation.  All rights reserved.  All
  * information contained herein is proprietary and confidential to NVIDIA
  * Corporation.  Any use, reproduction, or disclosure without the written
  * permission of NVIDIA Corporation is prohibited.
@@ -13,17 +13,32 @@
 #include "nv.h"
 #include "nv-freebsd.h"
 
+#include <sys/consio.h>
+#include <sys/fbio.h>
+#include <dev/syscons/syscons.h>
+
 MALLOC_DEFINE(M_NVIDIA, "nvidia", "NVIDIA memory allocations");
 TASKQUEUE_DEFINE_THREAD(nvidia);
 
 NV_STATUS NV_API_CALL os_alloc_mem(
     void **address,
-    NvU32 size
+    NvU64 size
 )
 {
-    /* XXX Fix me? (malloc flags) */
-    *address = malloc(size, M_NVIDIA, M_NOWAIT | M_ZERO);
-    return *address ? NV_OK : NV_ERR_GENERIC;
+    unsigned long alloc_size;
+
+    /*
+     * malloc takes an input of unsigned long (8 bytes in x64, 4 bytes in x86).
+     * To avoid truncation and wrong allocation, below check is required.
+     */
+    alloc_size = size;
+
+    if (alloc_size != size)
+        return NV_ERR_INVALID_PARAMETER;
+
+    // XXX Fix me? (malloc flags)
+    *address = malloc(alloc_size, M_NVIDIA, M_NOWAIT | M_ZERO);
+    return *address ? NV_OK : NV_ERR_NO_MEMORY;
 }
 
 void NV_API_CALL os_free_mem(void *address)
@@ -98,6 +113,12 @@ NvU32 NV_API_CALL os_get_current_process(void)
     return curproc->p_pid;
 }
 
+void NV_API_CALL os_get_current_process_name(char *buf, NvU32 len)
+{
+    // Unsupported
+    buf[0] = '\0';
+}
+
 NvU32 NV_API_CALL os_get_current_pasid(void)
 {
     // Unsupported. Return "0" as it's invalid PASID
@@ -279,7 +300,16 @@ void NV_API_CALL os_dbg_init(void)
 
 NV_STATUS NV_API_CALL os_schedule(void)
 {
-    return NV_ERR_NOT_SUPPORTED;
+    int ret = pause("sched", 1 /* timeout in 1/hz units */);
+
+    switch (ret)
+    {
+    case 0:
+    case EWOULDBLOCK:
+        return NV_OK;
+    default:
+        return NV_ERR_OPERATING_SYSTEM;
+    }
 }
 
 static void os_execute_work_item(void *context, int pending)
@@ -487,6 +517,16 @@ NvU32 NV_API_CALL os_string_length(const char* s)
     return strlen(s);
 }
 
+NvU32 NV_API_CALL os_strtoul(const char *str, char **endp, NvU32 base)
+{
+    return (NvU32)strtoul(str, endp, base);
+}
+
+NvS32 NV_API_CALL os_string_compare(const char *str1, const char *str2)
+{
+    return strcmp(str1, str2);
+}
+
 NvU32 NV_API_CALL os_get_page_size(void)
 {
     return PAGE_SIZE;
@@ -625,10 +665,9 @@ struct os_semaphore {
     struct mtx mutex_mtx;
     struct cv mutex_cv;
     NvS32  count;
-    NvS32  limit;
 };
 
-void* NV_API_CALL os_alloc_semaphore(NvU32 initialValue, NvU32 limit)
+void* NV_API_CALL os_alloc_semaphore(NvU32 initialValue)
 {
     NV_STATUS status;
     struct os_semaphore *os_sema;
@@ -643,7 +682,6 @@ void* NV_API_CALL os_alloc_semaphore(NvU32 initialValue, NvU32 limit)
     cv_init(&os_sema->mutex_cv, "os.sema_cv");
 
     os_sema->count = initialValue;
-    os_sema->limit = limit;
 
     return (void *)os_sema;
 }
@@ -713,11 +751,36 @@ BOOL NV_API_CALL os_iommu_is_snooping_enabled(void)
 
 void NV_API_CALL os_get_screen_info(
     NvU64 *pPhysicalAddress,
-    NvU64 *pFbSize
+    NvU16 *pFbWidth,
+    NvU16 *pFbHeight,
+    NvU16 *pFbDepth,
+    NvU16 *pFbPitch
 )
 {
+    const sc_softc_t *sc = sc_get_softc(0, SC_KERNEL_CONSOLE);
+
+    if (sc)
+    {
+        const video_adapter_t *adp = sc->adp;
+
+        if (adp)
+        {
+            const struct video_info *vi = &adp->va_info;
+
+            if (vi && (vi->vi_flags & V_INFO_LINEAR))
+            {
+                *pPhysicalAddress = vi->vi_buffer;
+                *pFbWidth = vi->vi_width;
+                *pFbHeight = vi->vi_height;
+                *pFbDepth = vi->vi_depth;
+                *pFbPitch = adp->va_line_width;
+                return;
+            }
+        }
+    }
+
     *pPhysicalAddress = 0;
-    *pFbSize = 0;
+    *pFbWidth = *pFbHeight = *pFbDepth = *pFbPitch = 0;
 }
 
 void NV_API_CALL os_register_compatible_ioctl(
@@ -889,3 +952,24 @@ NV_STATUS NV_API_CALL os_get_smbios_header(NvU64 *pSmbsAddr)
     return NV_ERR_NOT_SUPPORTED;
 }
 
+NV_STATUS NV_API_CALL os_get_acpi_rsdp_from_uefi
+(
+    NvU32  *pRsdpAddr
+)
+{
+    return NV_ERR_NOT_SUPPORTED;
+}
+
+void NV_API_CALL os_add_record_for_crashLog(void *pbuffer, NvU32 size)
+{
+}
+
+void NV_API_CALL os_delete_record_for_crashLog(void *pbuffer)
+{
+}
+
+NV_STATUS NV_API_CALL os_call_vgpu_vfio(void *pvgpu_vfio_info, NvU32 cmd_type)
+{
+    return NV_ERR_NOT_SUPPORTED;
+}
+
