@@ -122,3 +122,17 @@ NV_STATUS NV_API_CALL os_pci_write_dword(
     pci_write_config((device_t) handle, offset, value, 4);
     return NV_OK;
 }
+
+void os_remove_gpu(
+    NvU32 domain,
+    NvU8 bus,
+    NvU8 slot
+)
+{
+    return;
+}
+
+NvBool os_remove_gpu_supported(void)
+{
+    return NV_FALSE;
+}
