@@ -1,6 +1,6 @@
 /* _NVRM_COPYRIGHT_BEGIN_
  *
- * Copyright 2001-2011 by NVIDIA Corporation.  All rights reserved.  All
+ * Copyright 2001-2016 by NVIDIA Corporation.  All rights reserved.  All
  * information contained herein is proprietary and confidential to NVIDIA
  * Corporation.  Any use, reproduction, or disclosure without the written
  * permission of NVIDIA Corporation is prohibited.
@@ -21,7 +21,7 @@ void nvidia_update_registry(char *new_option_string)
     nv_parm_t *entry;
     nvidia_stack_t *sp;
     char *option_string = NULL;
-    char *ptr, *mod;
+    char *ptr;
     char *token;
     char *name, *value;
     NvU32 i, data;
@@ -30,14 +30,10 @@ void nvidia_update_registry(char *new_option_string)
     if (sp == NULL)
         return;
 
-    option_string = strdup(new_option_string, M_NVIDIA);
-    ptr = mod = option_string;
-
-    while (*ptr != '\0') {
-        if (!isspace(*ptr)) *mod++ = *ptr;
-        ptr++;
+    if ((option_string = rm_remove_spaces(new_option_string)) == NULL)
+    {
+        return;
     }
-    *mod = '\0';
 
     ptr = option_string;
 
@@ -63,7 +59,8 @@ void nvidia_update_registry(char *new_option_string)
 
     NV_UMA_ZONE_FREE_STACK(sp);
 
-    free(option_string, M_NVIDIA);
+    // Free the memory allocated by rm_remove_spaces()
+    os_free_mem(option_string);
 }
 
 #define NV_TUNABLE_MAX_STRLEN 128
