@@ -1,6 +1,6 @@
 /* _NVRM_COPYRIGHT_BEGIN_
  *
- * Copyright 2001-2014 by NVIDIA Corporation.  All rights reserved.  All
+ * Copyright 2001-2017 by NVIDIA Corporation.  All rights reserved.  All
  * information contained herein is proprietary and confidential to NVIDIA
  * Corporation.  Any use, reproduction, or disclosure without the written
  * permission of NVIDIA Corporation is prohibited.
@@ -26,7 +26,7 @@ nv_state_t nvidia_ctl_state;
 int nvidia_attach(device_t dev)
 {
     NV_STATUS status;
-    NvU32 i, pmc_boot_0, pmc_boot_42;
+    NvU32 i;
     struct nvidia_softc *sc;
     nv_state_t *nv;
 
@@ -55,24 +55,8 @@ int nvidia_attach(device_t dev)
 
     pci_enable_io(dev, SYS_RES_MEMORY);
 
-    if ((status = rm_is_supported_device(sc->attach_sp, nv, &pmc_boot_0,
-                                         &pmc_boot_42)) != NV_OK)
-    {
-        if ((status != NV_ERR_NOT_SUPPORTED) ||
-            !rm_is_legacy_arch(pmc_boot_0, pmc_boot_42))
-        {
-            nv_printf(NV_DBG_ERRORS,
-                "NVRM: The NVIDIA GPU %02x:%02x (PCI ID: %04x:%04x) installed\n"
-                "NVRM: in this system is not supported by the %s NVIDIA FreeBSD\n"
-                "NVRM: graphics driver release.  Please see 'Appendix A -\n"
-                "NVRM: Supported NVIDIA GPU Products' in this release's README,\n"
-                "NVRM: available on the FreeBSD graphics driver download page at\n"
-                "NVRM: www.nvidia.com.\n",
-                nv->pci_info.bus, nv->pci_info.slot, nv->pci_info.vendor_id, 
-                nv->pci_info.device_id, NV_VERSION_STRING);
-        }
+    if ((rm_is_supported_device(sc->attach_sp, nv)) != NV_OK)
         return ENXIO;
-    }
 
     for (i = 0; i < NV_GPU_NUM_BARS; i++) {
         if (sc->BAR_recs[i] != NULL) {
@@ -734,6 +718,13 @@ int nvidia_modevent(
 
             __nvidia_init_sp = sp;
 
+            if (!nvidia_lock_init_locks(sp, &nvidia_ctl_state)) {
+                rm_shutdown_rm(sp);
+                NV_UMA_ZONE_FREE_STACK(sp);
+                uma_zdestroy(nvidia_stack_t_zone);
+                return ENOMEM;
+            }
+
             callout_init(&sc->timer, CALLOUT_MPSAFE);
             sx_init(&sc->api_sx, "ctl.api_sx");
 
@@ -765,6 +756,9 @@ int nvidia_modevent(
             sx_destroy(&sc->api_sx);
 
             sp = __nvidia_init_sp;
+
+            nvidia_lock_destroy_locks(sp, nv);
+
             rm_shutdown_rm(sp);
 
             NV_UMA_ZONE_FREE_STACK(sp);
@@ -810,6 +804,23 @@ NV_STATUS NV_API_CALL nv_add_fd_memdesc_to_fd(
     return NV_ERR_NOT_SUPPORTED;
 }
 
+
+NV_STATUS NV_API_CALL nv_export_rm_object_to_fd(
+    NvHandle  hExportedRmObject,
+    NvS32     fd
+)
+{
+    return NV_ERR_NOT_SUPPORTED;
+}
+
+NV_STATUS NV_API_CALL nv_import_rm_object_from_fd(
+    NvS32     fd,
+    NvHandle *pExportedObject
+)
+{
+    return NV_ERR_NOT_SUPPORTED;
+}
+
 void NV_API_CALL nv_post_event(
     nv_state_t *nv,
     nv_event_t *event,
@@ -945,6 +956,10 @@ NV_STATUS NV_API_CALL nv_create_user_mapping_context(
     nv_state_t *nv,
     NvU64 address,
     NvU64 size,
+    NvU32 prot,
+    void *pAllocPriv,
+    NvU64 pageIndex,
+    void *file,
     void **ppPrivate
 )
 {
@@ -952,6 +967,14 @@ NV_STATUS NV_API_CALL nv_create_user_mapping_context(
     return NV_OK;
 }
 
+void NV_API_CALL nv_destroy_user_mapping_context(
+    nv_state_t *nv,
+    void *pFile,
+    void *pPrivate
+)
+{
+}
+
 NV_STATUS NV_API_CALL nv_alloc_user_mapping(
     nv_state_t *nv,
     void       *pAllocPrivate,
@@ -1654,3 +1677,15 @@ NV_STATUS NV_API_CALL nv_unregister_user_pages(
 {
     return NV_OK;
 }
+
+NV_STATUS NV_API_CALL nv_get_device_memory_config(
+    nv_state_t *nv,
+    NvU32 *pAddr,
+    NvU32 *pAddrGuest,
+    NvU32 *pAddrWidth,
+    NvU32 *pGranularity,
+    NvS32 *pNodeId
+)
+{
+    return NV_ERR_NOT_SUPPORTED;
+}
