@@ -1,5 +1,5 @@
 /*******************************************************************************
-    Copyright (c) 2015 NVidia Corporation
+    Copyright (c) 2015-2016 NVidia Corporation
 
     Permission is hereby granted, free of charge, to any person obtaining a copy
     of this software and associated documentation files (the "Software"), to
@@ -31,25 +31,11 @@ extern "C" {
 #include "nvtypes.h"
 #include "nvCpuUuid.h"
 
-#if defined(NV_WINDOWS)
-    #include "nv_dbg.h"
-#endif
-
 #ifndef NULL
 #define NULL ((void *)0)
 #endif
 
-#define NVL_DBG_INFO       0x0
-#define NVL_DBG_SETUP      0x1
-#define NVL_DBG_USERERRORS 0x2
-#define NVL_DBG_WARNINGS   0x3
-#define NVL_DBG_ERRORS     0x4
-
-#define DBG_MODULE_NVLINK_CORE  __FILE__, __LINE__, __FUNCTION__
-#define DBG_MODULE_IBMNPU       DBG_MODULE_NVLINK_CORE
-#define DBG_MODULE_EBRIDGE      DBG_MODULE_NVLINK_CORE
-
-#define NVL_FREE(x) nvl_free((void *)x)
+#define NVLINK_FREE(x) nvlink_free((void *)x)
 
 #if !defined(NV_WINDOWS)
     #if defined(NVCPU_X86)
@@ -82,7 +68,7 @@ struct nvlink_pci_info
     NvU8    bus;
     NvU8    device;
     NvU8    function;
-    NvU16   pciDeviceId;
+    NvU32   pciDeviceId;
     NvU32   irq;
     NvBool  intHooked;
     struct  nvlink_pci_bar_info bars[MAX_NVLINK_BARS];
@@ -109,39 +95,45 @@ typedef struct nvlink_conn_info nvlink_conn_info;
 
 
 // Memory management functions
-void *      NVLINK_API_CALL nvl_malloc(NvLength);
-void        NVLINK_API_CALL nvl_free(void *);
-void *      NVLINK_API_CALL nvl_memset(void *, int, NvLength);
-void *      NVLINK_API_CALL nvl_memcpy(void *, void *, NvLength);
-int         NVLINK_API_CALL nvlMemRd32(const volatile void *);
-void        NVLINK_API_CALL nvlMemWr32(volatile void *, unsigned int);
-int         NVLINK_API_CALL nvlMemRd64(const volatile void *);
-void        NVLINK_API_CALL nvlMemWr64(volatile void *, unsigned long long);
+void *      NVLINK_API_CALL nvlink_malloc(NvLength);
+void        NVLINK_API_CALL nvlink_free(void *);
+void *      NVLINK_API_CALL nvlink_memset(void *, int, NvLength);
+void *      NVLINK_API_CALL nvlink_memcpy(void *, void *, NvLength);
+int         NVLINK_API_CALL nvlink_memRd32(const volatile void *);
+void        NVLINK_API_CALL nvlink_memWr32(volatile void *, unsigned int);
+int         NVLINK_API_CALL nvlink_memRd64(const volatile void *);
+void        NVLINK_API_CALL nvlink_memWr64(volatile void *, unsigned long long);
 
 // String management functions
-char *      NVLINK_API_CALL nvl_strcpy(char *, const char *);
-NvLength    NVLINK_API_CALL nvl_strlen(const char *);
-int         NVLINK_API_CALL nvl_strcmp(const char *, const char *);
-int         NVLINK_API_CALL nvl_snprintf(char *, NvLength, const char *, ...);
+char *      NVLINK_API_CALL nvlink_strcpy(char *, const char *);
+NvLength    NVLINK_API_CALL nvlink_strlen(const char *);
+int         NVLINK_API_CALL nvlink_strcmp(const char *, const char *);
+int         NVLINK_API_CALL nvlink_snprintf(char *, NvLength, const char *, ...);
 
 // Locking support functions
-void *      NVLINK_API_CALL nvlAllocLock(void);
-void        NVLINK_API_CALL nvlAcquireLock(void *);
-NvBool      NVLINK_API_CALL nvlIsLockOwner(void *);
-void        NVLINK_API_CALL nvlReleaseLock(void *);
-void        NVLINK_API_CALL nvlFreeLock(void *);
+void *      NVLINK_API_CALL nvlink_allocLock(void);
+void        NVLINK_API_CALL nvlink_acquireLock(void *);
+NvBool      NVLINK_API_CALL nvlink_isLockOwner(void *);
+void        NVLINK_API_CALL nvlink_releaseLock(void *);
+void        NVLINK_API_CALL nvlink_freeLock(void *);
 
 // Miscellaneous functions
-void        NVLINK_API_CALL nvl_assert(int expression);
-void        NVLINK_API_CALL nvl_sleep(unsigned int ms);
+void        NVLINK_API_CALL nvlink_assert(int expression);
+void        NVLINK_API_CALL nvlink_sleep(unsigned int ms);
+void        NVLINK_API_CALL nvlink_print(const char *, int, const char *, int, const char *, ...);
 
-// Debug Prints
-#if defined(NV_WINDOWS)
-    #define NVLINK_PRINT(format_and_stuff) DBG_PRINTF(format_and_stuff)
-#else
-    #define NVLINK_PRINT(format_and_stuff) nvl_print format_and_stuff
-    void    NVLINK_API_CALL nvl_print(const char *, int, const char *, int, const char *, ...);
-#endif
+#define NVLINK_DBG_LEVEL_INFO       0x0
+#define NVLINK_DBG_LEVEL_SETUP      0x1
+#define NVLINK_DBG_LEVEL_USERERRORS 0x2
+#define NVLINK_DBG_LEVEL_WARNINGS   0x3
+#define NVLINK_DBG_LEVEL_ERRORS     0x4
+
+#define NVLINK_DBG_WHERE       __FILE__, __LINE__, __FUNCTION__
+#define NVLINK_DBG_INFO        NVLINK_DBG_WHERE, NVLINK_DBG_LEVEL_INFO
+#define NVLINK_DBG_SETUP       NVLINK_DBG_WHERE, NVLINK_DBG_LEVEL_SETUP
+#define NVLINK_DBG_USERERRORS  NVLINK_DBG_WHERE, NVLINK_DBG_LEVEL_USERERRORS
+#define NVLINK_DBG_WARNINGS    NVLINK_DBG_WHERE, NVLINK_DBG_LEVEL_WARNINGS
+#define NVLINK_DBG_ERRORS      NVLINK_DBG_WHERE, NVLINK_DBG_LEVEL_ERRORS
 
 #ifdef __cplusplus
 }
