@@ -1,6 +1,6 @@
 /* _NVRM_COPYRIGHT_BEGIN_
  *
- * Copyright 1999-2014 by NVIDIA Corporation.  All rights reserved.  All
+ * Copyright 1999-2016 by NVIDIA Corporation.  All rights reserved.  All
  * information contained herein is proprietary and confidential to NVIDIA
  * Corporation.  Any use, reproduction, or disclosure without the written
  * permission of NVIDIA Corporation is prohibited.
@@ -73,17 +73,20 @@ NvU32       NV_API_CALL  os_get_page_size            (void);
 NvU64       NV_API_CALL  os_get_page_mask            (void);
 NvU8        NV_API_CALL  os_get_page_shift           (void);
 NvU64       NV_API_CALL  os_get_num_phys_pages       (void);
-NV_STATUS   NV_API_CALL  os_alloc_mem                (void **, NvU32);
+NV_STATUS   NV_API_CALL  os_alloc_mem                (void **, NvU64);
 void        NV_API_CALL  os_free_mem                 (void *);
 NV_STATUS   NV_API_CALL  os_get_current_time         (NvU32 *, NvU32 *);
 NV_STATUS   NV_API_CALL  os_delay                    (NvU32);
 NV_STATUS   NV_API_CALL  os_delay_us                 (NvU32);
 NvU64       NV_API_CALL  os_get_cpu_frequency        (void);
 NvU32       NV_API_CALL  os_get_current_process      (void);
+void        NV_API_CALL  os_get_current_process_name (char *, NvU32);
 NvU32       NV_API_CALL  os_get_current_pasid        (void);
 NV_STATUS   NV_API_CALL  os_get_current_thread       (NvU64 *);
 char*       NV_API_CALL  os_string_copy              (char *, const char *);
 NvU32       NV_API_CALL  os_string_length            (const char *);
+NvU32       NV_API_CALL  os_strtoul                  (const char *, char **, NvU32);
+NvS32       NV_API_CALL  os_string_compare           (const char *, const char *);
 NvS32       NV_API_CALL  os_snprintf                 (char *, NvU32, const char *, ...);
 void        NV_API_CALL  os_log_error                (NvU32, NvU32, const char *, va_list);
 NvU8*       NV_API_CALL  os_mem_copy                 (NvU8 *, const NvU8 *, NvU32);
@@ -98,6 +101,8 @@ NV_STATUS   NV_API_CALL  os_pci_read_dword           (void *, NvU32, NvU32 *);
 NV_STATUS   NV_API_CALL  os_pci_write_byte           (void *, NvU32, NvU8);
 NV_STATUS   NV_API_CALL  os_pci_write_word           (void *, NvU32, NvU16);
 NV_STATUS   NV_API_CALL  os_pci_write_dword          (void *, NvU32, NvU32);
+NvBool      NV_API_CALL  os_remove_gpu_supported     (void);
+void        NV_API_CALL  os_remove_gpu               (NvU32, NvU8, NvU8);
 void*       NV_API_CALL  os_map_kernel_space         (NvU64, NvU64, NvU32, NvU32);
 void        NV_API_CALL  os_unmap_kernel_space       (void *, NvU64);
 void*       NV_API_CALL  os_map_user_space           (NvU64, NvU64, NvU32, NvU32, void **);
@@ -136,7 +141,7 @@ void        NV_API_CALL  os_free_mutex               (void *);
 NV_STATUS   NV_API_CALL  os_acquire_mutex            (void *);
 NV_STATUS   NV_API_CALL  os_cond_acquire_mutex       (void *);
 void        NV_API_CALL  os_release_mutex            (void *);
-void*       NV_API_CALL  os_alloc_semaphore          (NvU32, NvU32);
+void*       NV_API_CALL  os_alloc_semaphore          (NvU32);
 void        NV_API_CALL  os_free_semaphore           (void *);
 NV_STATUS   NV_API_CALL  os_acquire_semaphore        (void *);
 NV_STATUS   NV_API_CALL  os_release_semaphore        (void *);
@@ -151,7 +156,7 @@ NvBool      NV_API_CALL  os_is_xen_dom0              (void);
 NvBool      NV_API_CALL  os_is_vgx_hyper             (void);
 NV_STATUS   NV_API_CALL  os_inject_vgx_msi           (NvU16, NvU64, NvU32);
 NvBool      NV_API_CALL  os_is_grid_supported        (void);
-void        NV_API_CALL  os_get_screen_info          (NvU64 *, NvU64 *);
+void        NV_API_CALL  os_get_screen_info          (NvU64 *, NvU16 *, NvU16 *, NvU16 *, NvU16 *);
 void        NV_API_CALL  os_bug_check                (NvU32, const char *);
 NV_STATUS   NV_API_CALL  os_lock_user_pages          (void *, NvU64, void **);
 NV_STATUS   NV_API_CALL  os_lookup_user_io_memory    (void *, NvU64, NvU64 **);
@@ -159,6 +164,11 @@ NV_STATUS   NV_API_CALL  os_unlock_user_pages        (NvU64, void *);
 NV_STATUS   NV_API_CALL  os_match_mmap_offset        (void *, NvU64, NvU64 *);
 NV_STATUS   NV_API_CALL  os_get_euid                 (NvU32 *);
 NV_STATUS   NV_API_CALL  os_get_smbios_header        (NvU64 *pSmbsAddr);
+NV_STATUS   NV_API_CALL  os_get_acpi_rsdp_from_uefi  (NvU32 *);
+void        NV_API_CALL  os_add_record_for_crashLog  (void *, NvU32);
+void        NV_API_CALL  os_delete_record_for_crashLog (void *);
+NV_STATUS   NV_API_CALL  os_call_vgpu_vfio           (void *, NvU32);
+
 
 /*
  * ---------------------------------------------------------------------------
